# E0011: character is not allowed in identifiers

```config-for-examples
{
  "globals": {
    "“hello": true,
    "world”": true
  }
}
```

JavaScript allows certain non-ASCII characters in identifiers. Some characters,
including most emoji, are not allowed:

    function 💩AndDie() {
      throw new Error("Not yet implemented");
    }

    console.log(“hello, world”);

    let sounds = {
      🐶: "woof",
      🐮: "moo",
      🐱: "meow",
    };

To fix this error, rename your class, function, or variable:

    function die() {
      throw new Error("Not yet implemented");
    }

Alternatively, replace the symbols with ASCII:

    console.log("hello, world");

Alternatively, write the object key or method name as a string literal:

    let sounds = {
      "🐶": "woof",
      "🐮": "moo",
      "🐱": "meow",
    };
